@@ -1,168 +1,168 @@
-# context("tsPlot")
+context("tsPlot")
+
+test_that("tsPlot, no interactive", {
+  dta <- readAntares(areas = "all", links = "all", showProgress = FALSE)
+  testClass <- function(obj){
+    class(obj)[1] == 'combineWidgets'
+  }
+  listArgs <- list(noarg = list(x = dta, interactive = FALSE),
+                   elem = list(x = dta, interactive = FALSE, elements = "a"),
+                   elemS = list(x = dta, interactive = FALSE, elements = c("a", "b")),
+                   linkS = list(x = dta, table = "links", interactive = FALSE, elements = c("a - a_offshore")),
+                   linkSVarSel = list(x = dta, table = "links", interactive = FALSE,
+                                      elements = c("a - a_offshore"),
+                                      variable = "FLOW LIN._std"),
+                   bar = list(x = dta, interactive = FALSE, elements = "all", type = "barplot"),
+                   monotone = list(x = dta, interactive = FALSE, elements = "all", type = "monotone"),
+                   density = list(x = dta, interactive = FALSE, elements = "all", type = "density"),
+                   cdf = list(x = dta, interactive = FALSE, elements = "all", type = "cdf")
+  )
+
+  lapply(listArgs, function(X){
+    re1 <- do.call(tsPlot, X)
+    expect_true(testClass(re1))
+  })
+
+})
+
+
+
+test_that("tsPlot, no interactive return error", {
+
+  dta <- readAntares(areas = "all", links = "all", showProgress = FALSE)
+
+  expect_error(tsPlot(dta, interactive = FALSE, compare = "areas"))
+
+})
+
+# test_that("tsPlot, work with compare", {
 # 
-# test_that("tsPlot, no interactive", {
-#   dta <- readAntares(areas = "all", links = "all", showProgress = FALSE)
-#   testClass <- function(obj){
-#     class(obj)[1] == 'combineWidgets'
-#   }
-#   listArgs <- list(noarg = list(x = dta, interactive = FALSE),
-#                    elem = list(x = dta, interactive = FALSE, elements = "a"),
-#                    elemS = list(x = dta, interactive = FALSE, elements = c("a", "b")),
-#                    linkS = list(x = dta, table = "links", interactive = FALSE, elements = c("a - a_offshore")),
-#                    linkSVarSel = list(x = dta, table = "links", interactive = FALSE,
-#                                       elements = c("a - a_offshore"),
-#                                       variable = "FLOW LIN._std"),
-#                    bar = list(x = dta, interactive = FALSE, elements = "all", type = "barplot"),
-#                    monotone = list(x = dta, interactive = FALSE, elements = "all", type = "monotone"),
-#                    density = list(x = dta, interactive = FALSE, elements = "all", type = "density"),
-#                    cdf = list(x = dta, interactive = FALSE, elements = "all", type = "cdf")
-#   )
-#   
-#   lapply(listArgs, function(X){
-#     re1 <- do.call(tsPlot, X)
-#     expect_true(testClass(re1))
-#   })
-#   
-# })
+#   dta <- readAntares(areas = "all", links = "all", showProgress = FALSE, mcYears = "all")
+#   exList <-  tsPlot(x = dta, .runApp = FALSE, interactive = TRUE, compare = "mcYear")
+#   exList <- exList$init()
+#   #to get a param exList$getParams("tables")
+#   # exList$getValue("mcYear")
+#   exList$setValue("mcYear", 1, chartId = 1, reactive = FALSE)
+#   exList$setValue("mcYear", 2, chartId = 2, reactive = FALSE)
+#   exList$updateCharts()
+#   expect_equal(exList$getValue("tables"), "areas")
+#   expect_equal(exList$getValue("main"), "")
+#   expect_true(is(exList, "MWController"))
+#   expect_equal(exList$ncharts, 2)
+#   expect_equal(exList$ncol, 1)
+#   expect_equal(exList$nrow, 2)
+#   dataTsCompare <- .get_data_from_htmlwidget(exList, widgetsNumber = 1)
+#   timeEditValue <- "2018-05-06T18:00:00.000Z"
+#   indexHour <- grep(timeEditValue, dataTsCompare$hour)
+#   expect_gt(indexHour, 180)
+#   expect_equal(dataTsCompare$a[indexHour], 1627275)
 # 
+#   dataTsCompareMcYear2 <- .get_data_from_htmlwidget(exList, widgetsNumber = 2)
+#   expect_equal(dataTsCompareMcYear2$a[indexHour], 1432100)
 # 
-# 
-# test_that("tsPlot, no interactive return error", {
-#   
-#   dta <- readAntares(areas = "all", links = "all", showProgress = FALSE)
-#   
-#   expect_error(tsPlot(dta, interactive = FALSE, compare = "areas"))
-#   
-# })
-# 
-# # test_that("tsPlot, work with compare", {
-# #   
-# #   dta <- readAntares(areas = "all", links = "all", showProgress = FALSE, mcYears = "all")
-# #   exList <-  tsPlot(x = dta, .runApp = FALSE, interactive = TRUE, compare = "mcYear")
-# #   exList <- exList$init()
-# #   #to get a param exList$getParams("tables")
-# #   # exList$getValue("mcYear")
-# #   exList$setValue("mcYear", 1, chartId = 1, reactive = FALSE)
-# #   exList$setValue("mcYear", 2, chartId = 2, reactive = FALSE)
-# #   exList$updateCharts()
-# #   expect_equal(exList$getValue("tables"), "areas")
-# #   expect_equal(exList$getValue("main"), "")
-# #   expect_true(is(exList, "MWController"))
-# #   expect_equal(exList$ncharts, 2)
-# #   expect_equal(exList$ncol, 1)
-# #   expect_equal(exList$nrow, 2)
-# #   dataTsCompare <- .get_data_from_htmlwidget(exList, widgetsNumber = 1)
-# #   timeEditValue <- "2018-05-06T18:00:00.000Z"
-# #   indexHour <- grep(timeEditValue, dataTsCompare$hour)
-# #   expect_gt(indexHour, 180)
-# #   expect_equal(dataTsCompare$a[indexHour], 1627275)
-# #   
-# #   dataTsCompareMcYear2 <- .get_data_from_htmlwidget(exList, widgetsNumber = 2)
-# #   expect_equal(dataTsCompareMcYear2$a[indexHour], 1432100)
-# #   
-# # })
-# 
-# test_that("tsPlot, no interactive, x and refStudy are antaresDataTable", {
-#   myData1 <- readAntares(links = "all", showProgress = FALSE)
-#   myData2 <- readAntares(links = "all", showProgress = FALSE)
-#   myLink <- "a - a_offshore" 
-#   DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#   tsDa1 <- tsPlot(x = myData1, 
-#                   table = "links", 
-#                   elements = myLink,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
-#   timeEditValue <- "2018-04-25T00:00:00.000Z"
-#   indexHour <- grep(timeEditValue, dataTsDa1$hour)
-#   expect_gt(indexHour, 2)
-#   expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -9)
-#   tsDa2 <- tsPlot(x = myData1, 
-#                   refStudy = myData2,
-#                   table = "links", 
-#                   elements = myLink,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
-#   expect_equal(dataTsDa2$`a - a_offshore`[indexHour], 0)
-#   
-#   table <- "areas"
-#   myArea <- "b"
-#   myData1 <- readAntares(areas = myArea, showProgress = FALSE)
-#   myData2 <- readAntares(areas = myArea, showProgress = FALSE)
-#   tsDa1 <- tsPlot(x = myData1, 
-#                   table = table, 
-#                   elements = myArea,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
-#   expect_equal(dataTsDa1[[myArea]][[indexHour]], 2427150)
-#   tsDa2 <- tsPlot(x = myData1, 
-#                   refStudy = myData2,
-#                   table = table, 
-#                   elements = myArea,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
-#   expect_equal(dataTsDa2[[myArea]][[indexHour]], 0)
-# })
-# 
-# test_that("tsPlot, no interactive, x and refStudy are antaresDataList", {
-#   myArea <- "b"
-#   myLink <- "a - a_offshore" 
-#   myData1 <- readAntares(links = myLink, areas = myArea, showProgress = FALSE, mcYears = 1)
-#   myData2 <- readAntares(links = myLink, areas = myArea, showProgress = FALSE, mcYears = 1)
-#   DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#   tsDa1 <- tsPlot(x = myData1, 
-#                   table = "links", 
-#                   elements = myLink,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
-#   timeEditValue <- "2018-04-25T00:00:00.000Z"
-#   indexHour <- grep(timeEditValue, dataTsDa1$hour)
-#   expect_gt(indexHour, 2)
-#   expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -10)
-#   tsDa2 <- tsPlot(x = myData1, 
-#                   refStudy = myData2,
-#                   table = "links", 
-#                   elements = myLink,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
-#   expect_equal(dataTsDa2$`a - a_offshore`[indexHour], 0)
-# 
-#   #pb timeZone local (PC, Travis, etc)
-#   for (i in 0:5){
-#     timeEditShift <- lubridate::hours(i)
-#     timeEditMinus <- as.Date(timeEditValue) - timeEditShift
-#     timeEditPlus <- as.Date(timeEditValue) + timeEditShift
-#     myData2$links[ (time == timeEditMinus | time == timeEditPlus) & link == "a - a_offshore", `FLOW LIN.` := as.integer(`FLOW LIN.` + 2500)]
-#   }
-#   tsDa2 <- tsPlot(x = myData1, 
-#                   refStudy = myData2,
-#                   table = "links", 
-#                   elements = myLink,
-#                   type = "ts",
-#                   interactive = FALSE)
-#   dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
-#   expect_equal(dataTsDa2$`a - a_offshore`[indexHour], -2500)
-#   
 # })
 
+test_that("tsPlot, no interactive, x and refStudy are antaresDataTable", {
+  myData1 <- readAntares(links = "all", showProgress = FALSE)
+  myData2 <- readAntares(links = "all", showProgress = FALSE)
+  myLink <- "a - a_offshore"
+  DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
+  tsDa1 <- tsPlot(x = myData1,
+                  table = "links",
+                  elements = myLink,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
+  timeEditValue <- "2018-04-25T00:00:00.000Z"
+  indexHour <- grep(timeEditValue, dataTsDa1$hour)
+  expect_gt(indexHour, 2)
+  expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -9)
+  tsDa2 <- tsPlot(x = myData1,
+                  refStudy = myData2,
+                  table = "links",
+                  elements = myLink,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
+  expect_equal(dataTsDa2$`a - a_offshore`[indexHour], 0)
+
+  table <- "areas"
+  myArea <- "b"
+  myData1 <- readAntares(areas = myArea, showProgress = FALSE)
+  myData2 <- readAntares(areas = myArea, showProgress = FALSE)
+  tsDa1 <- tsPlot(x = myData1,
+                  table = table,
+                  elements = myArea,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
+  expect_equal(dataTsDa1[[myArea]][[indexHour]], 2427150)
+  tsDa2 <- tsPlot(x = myData1,
+                  refStudy = myData2,
+                  table = table,
+                  elements = myArea,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
+  expect_equal(dataTsDa2[[myArea]][[indexHour]], 0)
+})
+
+test_that("tsPlot, no interactive, x and refStudy are antaresDataList", {
+  myArea <- "b"
+  myLink <- "a - a_offshore"
+  myData1 <- readAntares(links = myLink, areas = myArea, showProgress = FALSE, mcYears = 1)
+  myData2 <- readAntares(links = myLink, areas = myArea, showProgress = FALSE, mcYears = 1)
+  DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
+  tsDa1 <- tsPlot(x = myData1,
+                  table = "links",
+                  elements = myLink,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa1 <- .get_data_from_htmlwidget(tsDa1)
+  timeEditValue <- "2018-04-25T00:00:00.000Z"
+  indexHour <- grep(timeEditValue, dataTsDa1$hour)
+  expect_gt(indexHour, 2)
+  expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -10)
+  tsDa2 <- tsPlot(x = myData1,
+                  refStudy = myData2,
+                  table = "links",
+                  elements = myLink,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
+  expect_equal(dataTsDa2$`a - a_offshore`[indexHour], 0)
+
+  #pb timeZone local (PC, Travis, etc)
+  for (i in 0:5){
+    timeEditShift <- lubridate::hours(i)
+    timeEditMinus <- as.Date(timeEditValue) - timeEditShift
+    timeEditPlus <- as.Date(timeEditValue) + timeEditShift
+    myData2$links[ (time == timeEditMinus | time == timeEditPlus) & link == "a - a_offshore", `FLOW LIN.` := as.integer(`FLOW LIN.` + 2500)]
+  }
+  tsDa2 <- tsPlot(x = myData1,
+                  refStudy = myData2,
+                  table = "links",
+                  elements = myLink,
+                  type = "ts",
+                  interactive = FALSE)
+  dataTsDa2 <- .get_data_from_htmlwidget(tsDa2)
+  expect_equal(dataTsDa2$`a - a_offshore`[indexHour], -2500)
+
+})
+
 # describe("tsPlot, no interactive, x is a list of antaresDataList and refStudy an antaresDataList", {
 #   myData1 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
 #   myData2 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
 #   myData3 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
 #   myData4 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
-#   
+# 
 #   myDataList <- list(myData2, myData3, myData4)
 #   myLink <- "a - a_offshore"
 #   mytables <- "links"
 #   myVariable <- "FLOW LIN."
 #   DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#   TsDaList <- tsPlot(x = myDataList, 
-#                   table = mytables, 
+#   TsDaList <- tsPlot(x = myDataList,
+#                   table = mytables,
 #                   elements = myLink,
 #                   type = "ts",
 #                   interactive = FALSE,
@@ -174,10 +174,10 @@
 #   indexHour <- grep(timeEditValue, dataTsDaList$hour)
 #   expect_gt(indexHour, 2)
 #   expect_equal(dataTsDaList$`a - a_offshore`[indexHour], -9)
-#   #with a refStudy 
+#   #with a refStudy
 #   TsDaList <- tsPlot(x = myDataList,
 #                      refStudy = myData1,
-#                      table = mytables, 
+#                      table = mytables,
 #                      elements = myLink,
 #                      type = "ts",
 #                      interactive = FALSE,
@@ -206,11 +206,11 @@
 # describe("tsPlot, interactive, x and refStudy are antaresDataTable", {
 #   myData1 <- readAntares(links = "all", showProgress = FALSE)
 #   myData2 <- readAntares(links = "all", showProgress = FALSE)
-#   myLink <- "a - a_offshore" 
+#   myLink <- "a - a_offshore"
 #   DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#   # no interactive 
-#   tsDa1 <- tsPlot(x = myData1, 
-#                   table = "links", 
+#   # no interactive
+#   tsDa1 <- tsPlot(x = myData1,
+#                   table = "links",
 #                   elements = myLink,
 #                   type = "ts",
 #                   interactive = FALSE)
@@ -219,9 +219,9 @@
 #   indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #   expect_gt(indexHour, 2)
 #   expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -9)
-#   # interactive 
-#   tsDa1Int <- tsPlot(x = myData1, 
-#                   table = "links", 
+#   # interactive
+#   tsDa1Int <- tsPlot(x = myData1,
+#                   table = "links",
 #                   elements = myLink,
 #                   type = "ts",
 #                   interactive = TRUE,
@@ -240,13 +240,13 @@
 #   indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #   expect_gt(indexHour, 2)
 #   expect_lt(indexHour, 50)
-#   # BUG with interactive 
-#   ## we must remove 24 hours ? 
-#   expect_equal(dataTsDAInt$`a - a_offshore`[indexHour - 24], -9)  
-#   # interactive with refStudy 
-#   tsDa1Int <- tsPlot(x = myData1, 
+#   # BUG with interactive
+#   ## we must remove 24 hours ?
+#   expect_equal(dataTsDAInt$`a - a_offshore`[indexHour - 24], -9)
+#   # interactive with refStudy
+#   tsDa1Int <- tsPlot(x = myData1,
 #                      refStudy = myData2,
-#                      table = "links", 
+#                      table = "links",
 #                      elements = myLink,
 #                      type = "ts",
 #                      interactive = TRUE,
@@ -257,7 +257,7 @@
 #   tsDa1Int$setValue("mcYear", "average", reactive = FALSE)
 #   dataTsDAInt <- .get_data_from_htmlwidget(tsDa1Int)
 #   expect_equal(dataTsDAInt$`a - a_offshore`[indexHour - 24], 0)
-#   
+# 
 #   # edit myData2 to have a diff != 0
 #   ## pb timeZone local (PC, Travis, etc)
 #   for (i in 0:5){
@@ -266,9 +266,9 @@
 #     timeEditPlus <- as.Date(timeEditValue) + timeEditShift
 #     myData2[ (time == timeEditMinus | time == timeEditPlus) & link == myLink, `FLOW LIN.` := as.integer(`FLOW LIN.` + 2500)]
 #   }
-#   tsDa1Int <- tsPlot(x = myData2, 
+#   tsDa1Int <- tsPlot(x = myData2,
 #                      refStudy = myData1,
-#                      table = "links", 
+#                      table = "links",
 #                      elements = myLink,
 #                      type = "ts",
 #                      interactive = TRUE,
@@ -284,11 +284,11 @@
 # describe("tsPlot, interactive, x and refStudy are antaresDataList", {
 #   myData1 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
 #   myData2 <- readAntares(links = "all", areas = "all", showProgress = FALSE)
-#   myArea <- "b" 
+#   myArea <- "b"
 #   DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#   # no interactive 
-#   tsDa1 <- tsPlot(x = myData1, 
-#                   table = "areas", 
+#   # no interactive
+#   tsDa1 <- tsPlot(x = myData1,
+#                   table = "areas",
 #                   elements = myArea,
 #                   type = "ts",
 #                   interactive = FALSE)
@@ -297,9 +297,9 @@
 #   indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #   expect_gt(indexHour, 2)
 #   expect_equal(dataTsDa1$b[indexHour], 2427150)
-#   # interactive 
-#   tsDa1Int <- tsPlot(x = myData1, 
-#                      table = "areas", 
+#   # interactive
+#   tsDa1Int <- tsPlot(x = myData1,
+#                      table = "areas",
 #                      elements = myArea,
 #                      type = "ts",
 #                      interactive = TRUE,
@@ -321,13 +321,13 @@
 #   indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #   expect_gt(indexHour, 2)
 #   expect_lt(indexHour, 50)
-#   # BUG with interactive 
-#   ## we must remove 24 hours ? 
-#   expect_equal(dataTsDAInt$b[indexHour - 24], 2427150)  
-#   # interactive with refStudy 
-#   tsDa1Int <- tsPlot(x = myData1, 
+#   # BUG with interactive
+#   ## we must remove 24 hours ?
+#   expect_equal(dataTsDAInt$b[indexHour - 24], 2427150)
+#   # interactive with refStudy
+#   tsDa1Int <- tsPlot(x = myData1,
 #                      refStudy = myData2,
-#                      table = "areas", 
+#                      table = "areas",
 #                      elements = myArea,
 #                      type = "ts",
 #                      interactive = TRUE,
@@ -338,7 +338,7 @@
 #   tsDa1Int$setValue("mcYear", "average", reactive = FALSE)
 #   dataTsDAInt <- .get_data_from_htmlwidget(tsDa1Int)
 #   expect_equal(dataTsDAInt$b[indexHour - 24], 0)
-#   
+# 
 #   # edit myData2 to have a diff != 0
 #   ## pb timeZone local (PC, Travis, etc)
 #   for (i in 0:5){
@@ -347,9 +347,9 @@
 #     timeEditPlus <- as.Date(timeEditValue) + timeEditShift
 #     myData2$areas[ (time == timeEditMinus | time == timeEditPlus) & area == myArea, `OV. COST` := as.integer(`OV. COST` + 2500)]
 #   }
-#   tsDa1Int <- tsPlot(x = myData2, 
+#   tsDa1Int <- tsPlot(x = myData2,
 #                      refStudy = myData1,
-#                      table = "areas", 
+#                      table = "areas",
 #                      elements = myArea,
 #                      type = "ts",
 #                      interactive = TRUE,
@@ -371,11 +371,11 @@
 #     skip_if_not(.runTsPlotTest)
 #     suppressMessages(writeAntaresH5(pathtemp, opts = opts, overwrite = TRUE))
 #     optsH5 <- setSimulationPath(pathtemp)
-#     myLink <- "a - a_offshore" 
+#     myLink <- "a - a_offshore"
 #     DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#     # no interactive 
-#     tsDa1 <- tsPlot(x = optsH5, 
-#                     table = "links", 
+#     # no interactive
+#     tsDa1 <- tsPlot(x = optsH5,
+#                     table = "links",
 #                     elements = myLink,
 #                     type = "ts",
 #                     interactive = FALSE)
@@ -384,10 +384,10 @@
 #     indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #     expect_gt(indexHour, 2)
 #     expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -9)
-#     #ref Study 
-#     tsDa1 <- tsPlot(x = optsH5, 
+#     #ref Study
+#     tsDa1 <- tsPlot(x = optsH5,
 #                     refStudy = optsH5,
-#                     table = "links", 
+#                     table = "links",
 #                     elements = myLink,
 #                     type = "ts",
 #                     interactive = FALSE)
@@ -395,7 +395,7 @@
 #     indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #     expect_gt(indexHour, 2)
 #     expect_equal(dataTsDa1$`a - a_offshore`[indexHour], 0)
-#     # Edit H5 file 
+#     # Edit H5 file
 #     ## create a new folder h5
 #     pathInitial <- file.path(dirname(pathtemp), basename(pathtemp))
 #     pathNewH5 <- file.path(pathInitial, "testH5")
@@ -405,22 +405,22 @@
 #     #write the study
 #     #windows pb ? pathNewH5 <- gsub("/", "\\", pathNewH5, fixed = TRUE)
 #     optsData <- antaresRead::setSimulationPath(path = studyPath)
-#     suppressWarnings(writeAntaresH5(path = pathNewH5, opts = optsData, 
+#     suppressWarnings(writeAntaresH5(path = pathNewH5, opts = optsData,
 #                                     overwrite = TRUE, supressMessages = TRUE))
-#     
+# 
 #     pathNewH5File <- file.path(pathNewH5, list.files(pathNewH5))
 #     .h5Antares_edit_variable(
-#       pathH5 = pathNewH5File, 
-#       link = myLink, 
-#       timeId = 1:100, 
-#       antVar = "FLOW LIN.", 
+#       pathH5 = pathNewH5File,
+#       link = myLink,
+#       timeId = 1:100,
+#       antVar = "FLOW LIN.",
 #       newValue = 15000
 #     )
-#     
+# 
 #     optsH5New <- setSimulationPath(path = pathNewH5File)
-#     tsDa1 <- tsPlot(x = optsH5New, 
+#     tsDa1 <- tsPlot(x = optsH5New,
 #                     refStudy = optsH5,
-#                     table = "links", 
+#                     table = "links",
 #                     elements = myLink,
 #                     type = "ts",
 #                     interactive = FALSE)
@@ -435,11 +435,11 @@
 #     skip_if_not(.runTsPlotTest)
 #     suppressMessages(writeAntaresH5(pathtemp, opts = opts, overwrite = TRUE))
 #     optsH5 <- setSimulationPath(pathtemp)
-#     
+# 
 #     # with new Studies H5 test if compare prodStack works
 #     ## create new folders h5
 #     pathInitial <- file.path(dirname(pathtemp), basename(pathtemp))
-#     
+# 
 #     listFolderToCreate <- c("testH5v2", "testH5v3", "testH5v4")
 #     for (folder in listFolderToCreate){
 #       pathNewH5 <- file.path(pathInitial, folder)
@@ -451,8 +451,8 @@
 #       optsData <- antaresRead::setSimulationPath(path = studyPath)
 #       suppressWarnings(
 #         writeAntaresH5(
-#           path = pathNewH5, 
-#           opts = optsData, 
+#           path = pathNewH5,
+#           opts = optsData,
 #           overwrite = TRUE,
 #           supressMessages = TRUE)
 #       )
@@ -463,10 +463,10 @@
 #     newValueFlow <- 15000
 #     myLink <- getLinks()[1]
 #     .h5Antares_edit_variable(
-#       pathH5 = pathH5FileToEdit, 
-#       link = myLink, 
-#       timeId = 1:100, 
-#       antVar = "FLOW LIN.", 
+#       pathH5 = pathH5FileToEdit,
+#       link = myLink,
+#       timeId = 1:100,
+#       antVar = "FLOW LIN.",
 #       newValue = newValueFlow
 #     )
 #     optsList <- list()
@@ -479,15 +479,15 @@
 #     #test the data from h5
 #     #get the data from the h5 file
 #     antaresDataRef <- readAntares(opts = optsH5, links = myLink)
-#     expect_equal(max(antaresDataListH5[[idWidgetToEdit]]$`FLOW LIN.`), newValueFlow) 
-#     expect_equal(max(antaresDataListH5[[1]]$`FLOW LIN.`), max(antaresDataRef$`FLOW LIN.`)) 
-#     expect_equal(max(antaresDataListH5[[3]]$`FLOW LIN.`), max(antaresDataRef$`FLOW LIN.`)) 
-#     # get the data from htmlwidget 
+#     expect_equal(max(antaresDataListH5[[idWidgetToEdit]]$`FLOW LIN.`), newValueFlow)
+#     expect_equal(max(antaresDataListH5[[1]]$`FLOW LIN.`), max(antaresDataRef$`FLOW LIN.`))
+#     expect_equal(max(antaresDataListH5[[3]]$`FLOW LIN.`), max(antaresDataRef$`FLOW LIN.`))
+#     # get the data from htmlwidget
 #     myArea <- "a"
 #     DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#     tsDa1 <- tsPlot(x = optsList, 
+#     tsDa1 <- tsPlot(x = optsList,
 #                     refStudy = optsH5,
-#                     table = "links", 
+#                     table = "links",
 #                     elements = myLink,
 #                     type = "ts",
 #                     interactive = FALSE)
@@ -505,11 +505,11 @@
 #     skip_if_not(.runTsPlotTest)
 #     suppressMessages(writeAntaresH5(pathtemp, opts = opts, overwrite = TRUE))
 #     optsH5 <- setSimulationPath(pathtemp)
-#     myLink <- "a - a_offshore" 
+#     myLink <- "a - a_offshore"
 #     DR <- c("2018-04-24 00:00:00 UTC", "2018-04-26 00:00:00 UTC")
-#     # no interactive 
-#     tsDa1 <- tsPlot(x = optsH5, 
-#                     table = "links", 
+#     # no interactive
+#     tsDa1 <- tsPlot(x = optsH5,
+#                     table = "links",
 #                     elements = myLink,
 #                     type = "ts",
 #                     interactive = FALSE)
@@ -530,7 +530,7 @@
 #     expect_true(is(tsDa1Int, "MWController"))
 #     expect_equal(tsDa1Int$ncharts, 1)
 #     expect_equal(tsDa1Int$ncol, 1)
-#     expect_equal(tsDa1Int$nrow, 1) 
+#     expect_equal(tsDa1Int$nrow, 1)
 #     expect_true(is((tsDa1Int$getValue("x_tranform")[[1]]), "antaresData"))
 #     tsDa1Int$setValue("mcYear", 1, reactive = TRUE)
 #     tsDa1Int$setValue("tables", "areas", reactive = TRUE)
@@ -551,7 +551,7 @@
 #     indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #     expect_gt(indexHour, 2)
 #     expect_equal(dataTsDa1$b[indexHour], 60262)
-#     # Edit H5 file 
+#     # Edit H5 file
 #     ## create a new folder h5
 #     pathInitial <- file.path(dirname(pathtemp), basename(pathtemp))
 #     pathNewH5 <- file.path(pathInitial, "testH5")
@@ -561,32 +561,32 @@
 #     #write the study
 #     #windows pb ? pathNewH5 <- gsub("/", "\\", pathNewH5, fixed = TRUE)
 #     optsData <- antaresRead::setSimulationPath(path = studyPath)
-#     suppressWarnings(writeAntaresH5(path = pathNewH5, opts = optsData, 
+#     suppressWarnings(writeAntaresH5(path = pathNewH5, opts = optsData,
 #                                     overwrite = TRUE, supressMessages = TRUE))
 #     pathNewH5File <- file.path(pathNewH5, list.files(pathNewH5))
 #     .h5Antares_edit_variable(
-#       pathH5 = pathNewH5File, 
-#       area = "b", 
-#       timeId = 1:100, 
-#       antVar = "LOAD", 
+#       pathH5 = pathNewH5File,
+#       area = "b",
+#       timeId = 1:100,
+#       antVar = "LOAD",
 #       newValue = 15000,
 #       mcYear = 1
 #     )
 #     optsH5New <- setSimulationPath(path = pathNewH5File)
-#     myData <- readAntares(areas = "b", 
-#                           select = "LOAD", 
+#     myData <- readAntares(areas = "b",
+#                           select = "LOAD",
 #                           opts = optsH5New,
 #                           mcYears = 1)
-#     myDataRef <- readAntares(areas = "b", 
-#                              select = "LOAD", 
+#     myDataRef <- readAntares(areas = "b",
+#                              select = "LOAD",
 #                              opts = optsH5,
 #                              mcYears = 1)
 #     expect_equal(myData[area == "b" & timeId == 2737, LOAD], 15000)
 #     expect_gt(myDataRef[area == "b" & timeId == 2737, LOAD], 16000)
-#     
-#     diffValue <- myData[area == "b" & timeId == 2737, LOAD] - 
+# 
+#     diffValue <- myData[area == "b" & timeId == 2737, LOAD] -
 #       myDataRef[area == "b" & timeId == 2737, LOAD]
-#     tsDa1Int <- tsPlot(x = optsH5New, 
+#     tsDa1Int <- tsPlot(x = optsH5New,
 #                     refStudy = optsH5,
 #                     type = "ts",
 #                     interactive = TRUE,
@@ -598,7 +598,7 @@
 #     expect_true(is(tsDa1Int, "MWController"))
 #     expect_equal(tsDa1Int$ncharts, 1)
 #     expect_equal(tsDa1Int$ncol, 1)
-#     expect_equal(tsDa1Int$nrow, 1) 
+#     expect_equal(tsDa1Int$nrow, 1)
 #     tsDa1Int$setValue("mcYear", 1, reactive = TRUE)
 #     tsDa1Int$setValue("tables", "areas", reactive = TRUE)
 #     tsDa1Int$setValue("elements", "b", reactive = FALSE)
@@ -613,7 +613,7 @@
 #     indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #     expect_equal(dataTsDa1$b[indexHour], diffValue)
 #     # for links, no refStudy
-#     tsDa1Int <- tsPlot(x = optsH5New, 
+#     tsDa1Int <- tsPlot(x = optsH5New,
 #                        type = "ts",
 #                        interactive = TRUE,
 #                        .runApp = FALSE,
@@ -624,7 +624,7 @@
 #     expect_true(is(tsDa1Int, "MWController"))
 #     expect_equal(tsDa1Int$ncharts, 1)
 #     expect_equal(tsDa1Int$ncol, 1)
-#     expect_equal(tsDa1Int$nrow, 1) 
+#     expect_equal(tsDa1Int$nrow, 1)
 #     tsDa1Int$setValue("mcYear", 1, reactive = TRUE)
 #     tsDa1Int$setValue("tables", "links", reactive = TRUE)
 #     tsDa1Int$setValue("elements", myLink, reactive = FALSE)
@@ -641,7 +641,7 @@
 #     indexHour <- grep(timeEditValue, dataTsDa1$hour)
 #     expect_equal(dataTsDa1$`a - a_offshore`[indexHour], -10)
 #     # for links, with refStudy
-#     tsDa1IntRef <- tsPlot(x = optsH5New, 
+#     tsDa1IntRef <- tsPlot(x = optsH5New,
 #                        refStudy = optsH5,
 #                        type = "ts",
 #                        interactive = TRUE,
@@ -653,7 +653,7 @@
 #     expect_true(is(tsDa1IntRef, "MWController"))
 #     expect_equal(tsDa1IntRef$ncharts, 1)
 #     expect_equal(tsDa1IntRef$ncol, 1)
-#     expect_equal(tsDa1IntRef$nrow, 1) 
+#     expect_equal(tsDa1IntRef$nrow, 1)
 #     expect_true(is((tsDa1IntRef$getValue("x_tranform")[[1]]), "antaresData"))
 #     tsDa1IntRef$setValue("mcYear", 1, reactive = TRUE)
 #     expect_equal(tsDa1IntRef$getValue("mcYear"), 1)
@@ -683,7 +683,7 @@
 #     skip_if_not(.runTsPlotTest)
 #     suppressMessages(writeAntaresH5(pathtemp, opts = opts, overwrite = TRUE))
 #     optsH5 <- setSimulationPath(pathtemp)
-#     
+# 
 #     # with new Studies H5 test if compare prodStack works
 #     ## create new folders h5
 #     pathInitial <- file.path(dirname(pathtemp), basename(pathtemp))
@@ -693,14 +693,14 @@
 #       if (!dir.exists(pathNewH5)){
 #         dir.create(pathNewH5)
 #       }
-#       
+# 
 #       #write the study
 #       #windows pb ? pathNewH5 <- gsub("/", "\\", pathNewH5, fixed = TRUE)
 #       optsData <- antaresRead::setSimulationPath(path = studyPath)
 #       suppressWarnings(
 #         writeAntaresH5(
-#           path = pathNewH5, 
-#           opts = optsData, 
+#           path = pathNewH5,
+#           opts = optsData,
 #           overwrite = TRUE,
 #           supressMessages = TRUE)
 #       )
@@ -713,10 +713,10 @@
 #     myVar <- "FLOW LIN."
 #     for (mcYearToTest in mcYearToTestList){
 #       .h5Antares_edit_variable(
-#         pathH5 = pathH5FileToEdit, 
+#         pathH5 = pathH5FileToEdit,
 #         link = myLink,
-#         timeId = 1:100, 
-#         antVar = myVar, 
+#         timeId = 1:100,
+#         antVar = myVar,
 #         newValue = newValueFlow,
 #         mcYear = mcYearToTest
 #       )
@@ -726,7 +726,7 @@
 #       for (i in 1:length(listFolderToCreate)){
 #         pathOptsI <- file.path(pathInitial, listFolderToCreate[[i]])
 #         optsList[[i]] <- setSimulationPath(path = pathOptsI)
-#         antaresDataListH5[[i]] <- readAntares(links = myLink, 
+#         antaresDataListH5[[i]] <- readAntares(links = myLink,
 #                                               mcYear = mcYearToTest,
 #                                               opts = optsList[[i]])
 #       }
@@ -741,18 +741,18 @@
 #       }
 #       expect_equal(antaresDataListH5[[1]]$`FLOW LIN.`[[indexHour]], valFlow)
 #       expect_equal(antaresDataListH5[[3]]$`FLOW LIN.`[[indexHour]], valFlow)
-#       
+# 
 #       if(!is.null(mcYearToTest)){
-#         expect_error(tsPlot(x = optsList, 
-#                             table = "links", 
+#         expect_error(tsPlot(x = optsList,
+#                             table = "links",
 #                             elements = myLink,
 #                             type = "ts",
 #                             interactive = FALSE,
 #                             mcYear = mcYearToTest),
 #                      "You can't use mcYear for h5 file when interactive is set to FALSE. You can use mcYearh5.")
 #       }
-#       tsPlotNoInt <-  tsPlot(x = optsList, 
-#                              table = "links", 
+#       tsPlotNoInt <-  tsPlot(x = optsList,
+#                              table = "links",
 #                              elements = myLink,
 #                              type = "ts",
 #                              interactive = FALSE,
@@ -775,7 +775,7 @@
 #       expect_true(is(tsPlotInt, "MWController"))
 #       expect_equal(tsPlotInt$ncharts, 3)
 #       expect_equal(tsPlotInt$ncol, 2)
-#       expect_equal(tsPlotInt$nrow, 2)  
+#       expect_equal(tsPlotInt$nrow, 2)
 #       tsPlotInt$setValue("mcYear", mcYearToTest, reactive = TRUE)
 #       tsPlotInt$setValue("tables", "links", reactive = TRUE)
 #       tsPlotInt$setValue("elements", myLink, reactive = TRUE)
@@ -806,7 +806,7 @@
 #       expect_equal(datatsPlotInt$`a - a_offshore`[[indexHour]], 50000)
 #       datatsPlotInt2 <- .get_data_from_htmlwidget(tsPlotInt, widgetsNumber = 1)
 #       indexHour <- grep(timeEditValue, datatsPlotInt2$hour)
-#       expect_equal(datatsPlotInt2$`a - a_offshore`[[indexHour]], valFlow)  
+#       expect_equal(datatsPlotInt2$`a - a_offshore`[[indexHour]], valFlow)
 #       #interactive with refStudy
 #       tsPlotIntRef <-  tsPlot(x = optsList,
 #                               refStudy = optsH5,
@@ -821,7 +821,7 @@
 #       expect_true(is(tsPlotIntRef, "MWController"))
 #       expect_equal(tsPlotIntRef$ncharts, 3)
 #       expect_equal(tsPlotIntRef$ncol, 2)
-#       expect_equal(tsPlotIntRef$nrow, 2)  
+#       expect_equal(tsPlotIntRef$nrow, 2)
 #       tsPlotIntRef$setValue("mcYear", mcYearToTest, reactive = TRUE)
 #       tsPlotIntRef$setValue("tables", "links", reactive = TRUE)
 #       tsPlotIntRef$setValue("elements", myLink, reactive = TRUE)
@@ -853,7 +853,7 @@
 #       expect_equal(datatsPlotIntRef$`a - a_offshore`[[indexHour]], 50000-(valFlow))
 #       datatsPlotIntRef2 <- .get_data_from_htmlwidget(tsPlotIntRef, widgetsNumber = 1)
 #       indexHour <- grep(timeEditValue, datatsPlotIntRef2$hour)
-#       expect_equal(datatsPlotIntRef2$`a - a_offshore`[[indexHour]], 0)  
+#       expect_equal(datatsPlotIntRef2$`a - a_offshore`[[indexHour]], 0)
 #     }
 #   }
 # })
